# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCompanyParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'address': 'BTAddressInfo',
        'description': 'str',
        'owner_id': 'str',
        'domain_prefix': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'address': 'address',
        'description': 'description',
        'owner_id': 'ownerId',
        'domain_prefix': 'domainPrefix'
    }

    def __init__(self, name=None, id=None, address=None, description=None, owner_id=None, domain_prefix=None):  # noqa: E501
        """BTCompanyParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._address = None
        self._description = None
        self._owner_id = None
        self._domain_prefix = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if address is not None:
            self.address = address
        if description is not None:
            self.description = description
        if owner_id is not None:
            self.owner_id = owner_id
        if domain_prefix is not None:
            self.domain_prefix = domain_prefix

    @property
    def name(self):
        """Gets the name of this BTCompanyParams.  # noqa: E501


        :return: The name of this BTCompanyParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTCompanyParams.


        :param name: The name of this BTCompanyParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTCompanyParams.  # noqa: E501


        :return: The id of this BTCompanyParams.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTCompanyParams.


        :param id: The id of this BTCompanyParams.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def address(self):
        """Gets the address of this BTCompanyParams.  # noqa: E501


        :return: The address of this BTCompanyParams.  # noqa: E501
        :rtype: BTAddressInfo
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this BTCompanyParams.


        :param address: The address of this BTCompanyParams.  # noqa: E501
        :type: BTAddressInfo
        """

        self._address = address

    @property
    def description(self):
        """Gets the description of this BTCompanyParams.  # noqa: E501


        :return: The description of this BTCompanyParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTCompanyParams.


        :param description: The description of this BTCompanyParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def owner_id(self):
        """Gets the owner_id of this BTCompanyParams.  # noqa: E501


        :return: The owner_id of this BTCompanyParams.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTCompanyParams.


        :param owner_id: The owner_id of this BTCompanyParams.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def domain_prefix(self):
        """Gets the domain_prefix of this BTCompanyParams.  # noqa: E501


        :return: The domain_prefix of this BTCompanyParams.  # noqa: E501
        :rtype: str
        """
        return self._domain_prefix

    @domain_prefix.setter
    def domain_prefix(self, domain_prefix):
        """Sets the domain_prefix of this BTCompanyParams.


        :param domain_prefix: The domain_prefix of this BTCompanyParams.  # noqa: E501
        :type: str
        """

        self._domain_prefix = domain_prefix

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCompanyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAssociativeDataParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'id_tag': 'str',
        'microversion_id': 'str',
        'data': 'list[BTNameValuePair]',
        'configuration': 'str',
        'workspace_id': 'str',
        'element_id': 'str',
        'document_microversion': 'str',
        'associative_data_id': 'str',
        'operation': 'str',
        'view_id': 'str',
        'occurrence_id': 'str',
        'is_hidden_base_view': 'bool',
        'version_id': 'str',
        'document_id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'id_tag': 'idTag',
        'microversion_id': 'microversionId',
        'data': 'data',
        'configuration': 'configuration',
        'workspace_id': 'workspaceId',
        'element_id': 'elementId',
        'document_microversion': 'documentMicroversion',
        'associative_data_id': 'associativeDataId',
        'operation': 'operation',
        'view_id': 'viewId',
        'occurrence_id': 'occurrenceId',
        'is_hidden_base_view': 'isHiddenBaseView',
        'version_id': 'versionId',
        'document_id': 'documentId'
    }

    def __init__(self, type=None, id_tag=None, microversion_id=None, data=None, configuration=None, workspace_id=None, element_id=None, document_microversion=None, associative_data_id=None, operation=None, view_id=None, occurrence_id=None, is_hidden_base_view=None, version_id=None, document_id=None):  # noqa: E501
        """BTAssociativeDataParams - a model defined in OpenAPI"""  # noqa: E501

        self._type = None
        self._id_tag = None
        self._microversion_id = None
        self._data = None
        self._configuration = None
        self._workspace_id = None
        self._element_id = None
        self._document_microversion = None
        self._associative_data_id = None
        self._operation = None
        self._view_id = None
        self._occurrence_id = None
        self._is_hidden_base_view = None
        self._version_id = None
        self._document_id = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if id_tag is not None:
            self.id_tag = id_tag
        if microversion_id is not None:
            self.microversion_id = microversion_id
        if data is not None:
            self.data = data
        if configuration is not None:
            self.configuration = configuration
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if element_id is not None:
            self.element_id = element_id
        if document_microversion is not None:
            self.document_microversion = document_microversion
        if associative_data_id is not None:
            self.associative_data_id = associative_data_id
        if operation is not None:
            self.operation = operation
        if view_id is not None:
            self.view_id = view_id
        if occurrence_id is not None:
            self.occurrence_id = occurrence_id
        if is_hidden_base_view is not None:
            self.is_hidden_base_view = is_hidden_base_view
        if version_id is not None:
            self.version_id = version_id
        if document_id is not None:
            self.document_id = document_id

    @property
    def type(self):
        """Gets the type of this BTAssociativeDataParams.  # noqa: E501


        :return: The type of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTAssociativeDataParams.


        :param type: The type of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["ONSHAPE_DRAWING_VIEW", "MODEL_TOPOLOGY", "MODEL_DEFINITION_FEATURE", "MODEL_DEFINITION_ENTITY", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def id_tag(self):
        """Gets the id_tag of this BTAssociativeDataParams.  # noqa: E501


        :return: The id_tag of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._id_tag

    @id_tag.setter
    def id_tag(self, id_tag):
        """Sets the id_tag of this BTAssociativeDataParams.


        :param id_tag: The id_tag of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._id_tag = id_tag

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The microversion_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTAssociativeDataParams.


        :param microversion_id: The microversion_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._microversion_id = microversion_id

    @property
    def data(self):
        """Gets the data of this BTAssociativeDataParams.  # noqa: E501


        :return: The data of this BTAssociativeDataParams.  # noqa: E501
        :rtype: list[BTNameValuePair]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this BTAssociativeDataParams.


        :param data: The data of this BTAssociativeDataParams.  # noqa: E501
        :type: list[BTNameValuePair]
        """

        self._data = data

    @property
    def configuration(self):
        """Gets the configuration of this BTAssociativeDataParams.  # noqa: E501


        :return: The configuration of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this BTAssociativeDataParams.


        :param configuration: The configuration of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._configuration = configuration

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The workspace_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTAssociativeDataParams.


        :param workspace_id: The workspace_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def element_id(self):
        """Gets the element_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The element_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._element_id

    @element_id.setter
    def element_id(self, element_id):
        """Sets the element_id of this BTAssociativeDataParams.


        :param element_id: The element_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._element_id = element_id

    @property
    def document_microversion(self):
        """Gets the document_microversion of this BTAssociativeDataParams.  # noqa: E501


        :return: The document_microversion of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._document_microversion

    @document_microversion.setter
    def document_microversion(self, document_microversion):
        """Sets the document_microversion of this BTAssociativeDataParams.


        :param document_microversion: The document_microversion of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._document_microversion = document_microversion

    @property
    def associative_data_id(self):
        """Gets the associative_data_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The associative_data_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._associative_data_id

    @associative_data_id.setter
    def associative_data_id(self, associative_data_id):
        """Sets the associative_data_id of this BTAssociativeDataParams.


        :param associative_data_id: The associative_data_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._associative_data_id = associative_data_id

    @property
    def operation(self):
        """Gets the operation of this BTAssociativeDataParams.  # noqa: E501


        :return: The operation of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this BTAssociativeDataParams.


        :param operation: The operation of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """
        allowed_values = ["ADD", "REMOVE", "UPDATE"]  # noqa: E501
        if operation not in allowed_values:
            raise ValueError(
                "Invalid value for `operation` ({0}), must be one of {1}"  # noqa: E501
                .format(operation, allowed_values)
            )

        self._operation = operation

    @property
    def view_id(self):
        """Gets the view_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The view_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._view_id

    @view_id.setter
    def view_id(self, view_id):
        """Sets the view_id of this BTAssociativeDataParams.


        :param view_id: The view_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._view_id = view_id

    @property
    def occurrence_id(self):
        """Gets the occurrence_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The occurrence_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._occurrence_id

    @occurrence_id.setter
    def occurrence_id(self, occurrence_id):
        """Sets the occurrence_id of this BTAssociativeDataParams.


        :param occurrence_id: The occurrence_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._occurrence_id = occurrence_id

    @property
    def is_hidden_base_view(self):
        """Gets the is_hidden_base_view of this BTAssociativeDataParams.  # noqa: E501


        :return: The is_hidden_base_view of this BTAssociativeDataParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden_base_view

    @is_hidden_base_view.setter
    def is_hidden_base_view(self, is_hidden_base_view):
        """Sets the is_hidden_base_view of this BTAssociativeDataParams.


        :param is_hidden_base_view: The is_hidden_base_view of this BTAssociativeDataParams.  # noqa: E501
        :type: bool
        """

        self._is_hidden_base_view = is_hidden_base_view

    @property
    def version_id(self):
        """Gets the version_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The version_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTAssociativeDataParams.


        :param version_id: The version_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def document_id(self):
        """Gets the document_id of this BTAssociativeDataParams.  # noqa: E501


        :return: The document_id of this BTAssociativeDataParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTAssociativeDataParams.


        :param document_id: The document_id of this BTAssociativeDataParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAssociativeDataParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTRootDiffInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'target_version_id': 'str',
        'target_workspace_id': 'str',
        'source_configuration': 'str',
        'target_configuration': 'str',
        'source_microversion_id': 'str',
        'source_version_id': 'str',
        'source_workspace_id': 'str',
        'target_microversion_id': 'str',
        'type': 'str',
        'changes': 'dict(str, BTDiffInfo)',
        'source_id': 'str',
        'collection_changes': 'dict(str, list[BTDiffInfo])',
        'target_id': 'str',
        'source_value': 'str',
        'target_value': 'str'
    }

    attribute_map = {
        'target_version_id': 'targetVersionId',
        'target_workspace_id': 'targetWorkspaceId',
        'source_configuration': 'sourceConfiguration',
        'target_configuration': 'targetConfiguration',
        'source_microversion_id': 'sourceMicroversionId',
        'source_version_id': 'sourceVersionId',
        'source_workspace_id': 'sourceWorkspaceId',
        'target_microversion_id': 'targetMicroversionId',
        'type': 'type',
        'changes': 'changes',
        'source_id': 'sourceId',
        'collection_changes': 'collectionChanges',
        'target_id': 'targetId',
        'source_value': 'sourceValue',
        'target_value': 'targetValue'
    }

    def __init__(self, target_version_id=None, target_workspace_id=None, source_configuration=None, target_configuration=None, source_microversion_id=None, source_version_id=None, source_workspace_id=None, target_microversion_id=None, type=None, changes=None, source_id=None, collection_changes=None, target_id=None, source_value=None, target_value=None):  # noqa: E501
        """BTRootDiffInfo - a model defined in OpenAPI"""  # noqa: E501

        self._target_version_id = None
        self._target_workspace_id = None
        self._source_configuration = None
        self._target_configuration = None
        self._source_microversion_id = None
        self._source_version_id = None
        self._source_workspace_id = None
        self._target_microversion_id = None
        self._type = None
        self._changes = None
        self._source_id = None
        self._collection_changes = None
        self._target_id = None
        self._source_value = None
        self._target_value = None
        self.discriminator = None

        if target_version_id is not None:
            self.target_version_id = target_version_id
        if target_workspace_id is not None:
            self.target_workspace_id = target_workspace_id
        if source_configuration is not None:
            self.source_configuration = source_configuration
        if target_configuration is not None:
            self.target_configuration = target_configuration
        if source_microversion_id is not None:
            self.source_microversion_id = source_microversion_id
        if source_version_id is not None:
            self.source_version_id = source_version_id
        if source_workspace_id is not None:
            self.source_workspace_id = source_workspace_id
        if target_microversion_id is not None:
            self.target_microversion_id = target_microversion_id
        if type is not None:
            self.type = type
        if changes is not None:
            self.changes = changes
        if source_id is not None:
            self.source_id = source_id
        if collection_changes is not None:
            self.collection_changes = collection_changes
        if target_id is not None:
            self.target_id = target_id
        if source_value is not None:
            self.source_value = source_value
        if target_value is not None:
            self.target_value = target_value

    @property
    def target_version_id(self):
        """Gets the target_version_id of this BTRootDiffInfo.  # noqa: E501


        :return: The target_version_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_version_id

    @target_version_id.setter
    def target_version_id(self, target_version_id):
        """Sets the target_version_id of this BTRootDiffInfo.


        :param target_version_id: The target_version_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_version_id = target_version_id

    @property
    def target_workspace_id(self):
        """Gets the target_workspace_id of this BTRootDiffInfo.  # noqa: E501


        :return: The target_workspace_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_workspace_id

    @target_workspace_id.setter
    def target_workspace_id(self, target_workspace_id):
        """Sets the target_workspace_id of this BTRootDiffInfo.


        :param target_workspace_id: The target_workspace_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_workspace_id = target_workspace_id

    @property
    def source_configuration(self):
        """Gets the source_configuration of this BTRootDiffInfo.  # noqa: E501


        :return: The source_configuration of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_configuration

    @source_configuration.setter
    def source_configuration(self, source_configuration):
        """Sets the source_configuration of this BTRootDiffInfo.


        :param source_configuration: The source_configuration of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_configuration = source_configuration

    @property
    def target_configuration(self):
        """Gets the target_configuration of this BTRootDiffInfo.  # noqa: E501


        :return: The target_configuration of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_configuration

    @target_configuration.setter
    def target_configuration(self, target_configuration):
        """Sets the target_configuration of this BTRootDiffInfo.


        :param target_configuration: The target_configuration of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_configuration = target_configuration

    @property
    def source_microversion_id(self):
        """Gets the source_microversion_id of this BTRootDiffInfo.  # noqa: E501


        :return: The source_microversion_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_microversion_id

    @source_microversion_id.setter
    def source_microversion_id(self, source_microversion_id):
        """Sets the source_microversion_id of this BTRootDiffInfo.


        :param source_microversion_id: The source_microversion_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_microversion_id = source_microversion_id

    @property
    def source_version_id(self):
        """Gets the source_version_id of this BTRootDiffInfo.  # noqa: E501


        :return: The source_version_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_version_id

    @source_version_id.setter
    def source_version_id(self, source_version_id):
        """Sets the source_version_id of this BTRootDiffInfo.


        :param source_version_id: The source_version_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_version_id = source_version_id

    @property
    def source_workspace_id(self):
        """Gets the source_workspace_id of this BTRootDiffInfo.  # noqa: E501


        :return: The source_workspace_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_workspace_id

    @source_workspace_id.setter
    def source_workspace_id(self, source_workspace_id):
        """Sets the source_workspace_id of this BTRootDiffInfo.


        :param source_workspace_id: The source_workspace_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_workspace_id = source_workspace_id

    @property
    def target_microversion_id(self):
        """Gets the target_microversion_id of this BTRootDiffInfo.  # noqa: E501


        :return: The target_microversion_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_microversion_id

    @target_microversion_id.setter
    def target_microversion_id(self, target_microversion_id):
        """Sets the target_microversion_id of this BTRootDiffInfo.


        :param target_microversion_id: The target_microversion_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_microversion_id = target_microversion_id

    @property
    def type(self):
        """Gets the type of this BTRootDiffInfo.  # noqa: E501


        :return: The type of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTRootDiffInfo.


        :param type: The type of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "MOVED", "MODIFIED", "MOVED_AND_MODIFIED", "ADDED", "DELETED", "UNKNOWN"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def changes(self):
        """Gets the changes of this BTRootDiffInfo.  # noqa: E501


        :return: The changes of this BTRootDiffInfo.  # noqa: E501
        :rtype: dict(str, BTDiffInfo)
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """Sets the changes of this BTRootDiffInfo.


        :param changes: The changes of this BTRootDiffInfo.  # noqa: E501
        :type: dict(str, BTDiffInfo)
        """

        self._changes = changes

    @property
    def source_id(self):
        """Gets the source_id of this BTRootDiffInfo.  # noqa: E501


        :return: The source_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this BTRootDiffInfo.


        :param source_id: The source_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_id = source_id

    @property
    def collection_changes(self):
        """Gets the collection_changes of this BTRootDiffInfo.  # noqa: E501


        :return: The collection_changes of this BTRootDiffInfo.  # noqa: E501
        :rtype: dict(str, list[BTDiffInfo])
        """
        return self._collection_changes

    @collection_changes.setter
    def collection_changes(self, collection_changes):
        """Sets the collection_changes of this BTRootDiffInfo.


        :param collection_changes: The collection_changes of this BTRootDiffInfo.  # noqa: E501
        :type: dict(str, list[BTDiffInfo])
        """

        self._collection_changes = collection_changes

    @property
    def target_id(self):
        """Gets the target_id of this BTRootDiffInfo.  # noqa: E501


        :return: The target_id of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this BTRootDiffInfo.


        :param target_id: The target_id of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def source_value(self):
        """Gets the source_value of this BTRootDiffInfo.  # noqa: E501


        :return: The source_value of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_value

    @source_value.setter
    def source_value(self, source_value):
        """Sets the source_value of this BTRootDiffInfo.


        :param source_value: The source_value of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._source_value = source_value

    @property
    def target_value(self):
        """Gets the target_value of this BTRootDiffInfo.  # noqa: E501


        :return: The target_value of this BTRootDiffInfo.  # noqa: E501
        :rtype: str
        """
        return self._target_value

    @target_value.setter
    def target_value(self, target_value):
        """Sets the target_value of this BTRootDiffInfo.


        :param target_value: The target_value of this BTRootDiffInfo.  # noqa: E501
        :type: str
        """

        self._target_value = target_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTRootDiffInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Operation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'tags': 'list[str]',
        'summary': 'str',
        'description': 'str',
        'external_docs': 'ExternalDocumentation',
        'operation_id': 'str',
        'parameters': 'list[Parameter]',
        'request_body': 'RequestBody',
        'responses': 'OperationResponses',
        'callbacks': 'dict(str, Callback)',
        'deprecated': 'bool',
        'security': 'list[SecurityRequirement]',
        'servers': 'list[Server]',
        'extensions': 'dict(str, object)'
    }

    attribute_map = {
        'tags': 'tags',
        'summary': 'summary',
        'description': 'description',
        'external_docs': 'externalDocs',
        'operation_id': 'operationId',
        'parameters': 'parameters',
        'request_body': 'requestBody',
        'responses': 'responses',
        'callbacks': 'callbacks',
        'deprecated': 'deprecated',
        'security': 'security',
        'servers': 'servers',
        'extensions': 'extensions'
    }

    def __init__(self, tags=None, summary=None, description=None, external_docs=None, operation_id=None, parameters=None, request_body=None, responses=None, callbacks=None, deprecated=None, security=None, servers=None, extensions=None):  # noqa: E501
        """Operation - a model defined in OpenAPI"""  # noqa: E501

        self._tags = None
        self._summary = None
        self._description = None
        self._external_docs = None
        self._operation_id = None
        self._parameters = None
        self._request_body = None
        self._responses = None
        self._callbacks = None
        self._deprecated = None
        self._security = None
        self._servers = None
        self._extensions = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if summary is not None:
            self.summary = summary
        if description is not None:
            self.description = description
        if external_docs is not None:
            self.external_docs = external_docs
        if operation_id is not None:
            self.operation_id = operation_id
        if parameters is not None:
            self.parameters = parameters
        if request_body is not None:
            self.request_body = request_body
        if responses is not None:
            self.responses = responses
        if callbacks is not None:
            self.callbacks = callbacks
        if deprecated is not None:
            self.deprecated = deprecated
        if security is not None:
            self.security = security
        if servers is not None:
            self.servers = servers
        if extensions is not None:
            self.extensions = extensions

    @property
    def tags(self):
        """Gets the tags of this Operation.  # noqa: E501


        :return: The tags of this Operation.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Operation.


        :param tags: The tags of this Operation.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def summary(self):
        """Gets the summary of this Operation.  # noqa: E501


        :return: The summary of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Operation.


        :param summary: The summary of this Operation.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def description(self):
        """Gets the description of this Operation.  # noqa: E501


        :return: The description of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Operation.


        :param description: The description of this Operation.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def external_docs(self):
        """Gets the external_docs of this Operation.  # noqa: E501


        :return: The external_docs of this Operation.  # noqa: E501
        :rtype: ExternalDocumentation
        """
        return self._external_docs

    @external_docs.setter
    def external_docs(self, external_docs):
        """Sets the external_docs of this Operation.


        :param external_docs: The external_docs of this Operation.  # noqa: E501
        :type: ExternalDocumentation
        """

        self._external_docs = external_docs

    @property
    def operation_id(self):
        """Gets the operation_id of this Operation.  # noqa: E501


        :return: The operation_id of this Operation.  # noqa: E501
        :rtype: str
        """
        return self._operation_id

    @operation_id.setter
    def operation_id(self, operation_id):
        """Sets the operation_id of this Operation.


        :param operation_id: The operation_id of this Operation.  # noqa: E501
        :type: str
        """

        self._operation_id = operation_id

    @property
    def parameters(self):
        """Gets the parameters of this Operation.  # noqa: E501


        :return: The parameters of this Operation.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Operation.


        :param parameters: The parameters of this Operation.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def request_body(self):
        """Gets the request_body of this Operation.  # noqa: E501


        :return: The request_body of this Operation.  # noqa: E501
        :rtype: RequestBody
        """
        return self._request_body

    @request_body.setter
    def request_body(self, request_body):
        """Sets the request_body of this Operation.


        :param request_body: The request_body of this Operation.  # noqa: E501
        :type: RequestBody
        """

        self._request_body = request_body

    @property
    def responses(self):
        """Gets the responses of this Operation.  # noqa: E501


        :return: The responses of this Operation.  # noqa: E501
        :rtype: OperationResponses
        """
        return self._responses

    @responses.setter
    def responses(self, responses):
        """Sets the responses of this Operation.


        :param responses: The responses of this Operation.  # noqa: E501
        :type: OperationResponses
        """

        self._responses = responses

    @property
    def callbacks(self):
        """Gets the callbacks of this Operation.  # noqa: E501


        :return: The callbacks of this Operation.  # noqa: E501
        :rtype: dict(str, Callback)
        """
        return self._callbacks

    @callbacks.setter
    def callbacks(self, callbacks):
        """Sets the callbacks of this Operation.


        :param callbacks: The callbacks of this Operation.  # noqa: E501
        :type: dict(str, Callback)
        """

        self._callbacks = callbacks

    @property
    def deprecated(self):
        """Gets the deprecated of this Operation.  # noqa: E501


        :return: The deprecated of this Operation.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this Operation.


        :param deprecated: The deprecated of this Operation.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def security(self):
        """Gets the security of this Operation.  # noqa: E501


        :return: The security of this Operation.  # noqa: E501
        :rtype: list[SecurityRequirement]
        """
        return self._security

    @security.setter
    def security(self, security):
        """Sets the security of this Operation.


        :param security: The security of this Operation.  # noqa: E501
        :type: list[SecurityRequirement]
        """

        self._security = security

    @property
    def servers(self):
        """Gets the servers of this Operation.  # noqa: E501


        :return: The servers of this Operation.  # noqa: E501
        :rtype: list[Server]
        """
        return self._servers

    @servers.setter
    def servers(self, servers):
        """Sets the servers of this Operation.


        :param servers: The servers of this Operation.  # noqa: E501
        :type: list[Server]
        """

        self._servers = servers

    @property
    def extensions(self):
        """Gets the extensions of this Operation.  # noqa: E501


        :return: The extensions of this Operation.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._extensions

    @extensions.setter
    def extensions(self, extensions):
        """Sets the extensions of this Operation.


        :param extensions: The extensions of this Operation.  # noqa: E501
        :type: dict(str, object)
        """

        self._extensions = extensions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Operation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTAppElementHistoryInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'changes': 'list[BTAppElementHistoryEntryInfo]',
        'error_code': 'int',
        'error_value': 'str',
        'error_description': 'str'
    }

    attribute_map = {
        'changes': 'changes',
        'error_code': 'errorCode',
        'error_value': 'errorValue',
        'error_description': 'errorDescription'
    }

    def __init__(self, changes=None, error_code=None, error_value=None, error_description=None):  # noqa: E501
        """BTAppElementHistoryInfo - a model defined in OpenAPI"""  # noqa: E501

        self._changes = None
        self._error_code = None
        self._error_value = None
        self._error_description = None
        self.discriminator = None

        if changes is not None:
            self.changes = changes
        if error_code is not None:
            self.error_code = error_code
        if error_value is not None:
            self.error_value = error_value
        if error_description is not None:
            self.error_description = error_description

    @property
    def changes(self):
        """Gets the changes of this BTAppElementHistoryInfo.  # noqa: E501


        :return: The changes of this BTAppElementHistoryInfo.  # noqa: E501
        :rtype: list[BTAppElementHistoryEntryInfo]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """Sets the changes of this BTAppElementHistoryInfo.


        :param changes: The changes of this BTAppElementHistoryInfo.  # noqa: E501
        :type: list[BTAppElementHistoryEntryInfo]
        """

        self._changes = changes

    @property
    def error_code(self):
        """Gets the error_code of this BTAppElementHistoryInfo.  # noqa: E501


        :return: The error_code of this BTAppElementHistoryInfo.  # noqa: E501
        :rtype: int
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this BTAppElementHistoryInfo.


        :param error_code: The error_code of this BTAppElementHistoryInfo.  # noqa: E501
        :type: int
        """

        self._error_code = error_code

    @property
    def error_value(self):
        """Gets the error_value of this BTAppElementHistoryInfo.  # noqa: E501


        :return: The error_value of this BTAppElementHistoryInfo.  # noqa: E501
        :rtype: str
        """
        return self._error_value

    @error_value.setter
    def error_value(self, error_value):
        """Sets the error_value of this BTAppElementHistoryInfo.


        :param error_value: The error_value of this BTAppElementHistoryInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["OK", "TRANSACTION_CONFLICT", "NOT_FOUND", "INCONSISTENT_CHANGES"]  # noqa: E501
        if error_value not in allowed_values:
            raise ValueError(
                "Invalid value for `error_value` ({0}), must be one of {1}"  # noqa: E501
                .format(error_value, allowed_values)
            )

        self._error_value = error_value

    @property
    def error_description(self):
        """Gets the error_description of this BTAppElementHistoryInfo.  # noqa: E501


        :return: The error_description of this BTAppElementHistoryInfo.  # noqa: E501
        :rtype: str
        """
        return self._error_description

    @error_description.setter
    def error_description(self, error_description):
        """Sets the error_description of this BTAppElementHistoryInfo.


        :param error_description: The error_description of this BTAppElementHistoryInfo.  # noqa: E501
        :type: str
        """

        self._error_description = error_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTAppElementHistoryInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTSubstituteApproverParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'identity': 'BTIdentityParams',
        'enabled': 'bool',
        'company_id': 'str'
    }

    attribute_map = {
        'identity': 'identity',
        'enabled': 'enabled',
        'company_id': 'companyId'
    }

    def __init__(self, identity=None, enabled=None, company_id=None):  # noqa: E501
        """BTSubstituteApproverParams - a model defined in OpenAPI"""  # noqa: E501

        self._identity = None
        self._enabled = None
        self._company_id = None
        self.discriminator = None

        if identity is not None:
            self.identity = identity
        if enabled is not None:
            self.enabled = enabled
        if company_id is not None:
            self.company_id = company_id

    @property
    def identity(self):
        """Gets the identity of this BTSubstituteApproverParams.  # noqa: E501


        :return: The identity of this BTSubstituteApproverParams.  # noqa: E501
        :rtype: BTIdentityParams
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this BTSubstituteApproverParams.


        :param identity: The identity of this BTSubstituteApproverParams.  # noqa: E501
        :type: BTIdentityParams
        """

        self._identity = identity

    @property
    def enabled(self):
        """Gets the enabled of this BTSubstituteApproverParams.  # noqa: E501


        :return: The enabled of this BTSubstituteApproverParams.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this BTSubstituteApproverParams.


        :param enabled: The enabled of this BTSubstituteApproverParams.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def company_id(self):
        """Gets the company_id of this BTSubstituteApproverParams.  # noqa: E501


        :return: The company_id of this BTSubstituteApproverParams.  # noqa: E501
        :rtype: str
        """
        return self._company_id

    @company_id.setter
    def company_id(self, company_id):
        """Sets the company_id of this BTSubstituteApproverParams.


        :param company_id: The company_id of this BTSubstituteApproverParams.  # noqa: E501
        :type: str
        """

        self._company_id = company_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTSubstituteApproverParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Subscription(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'application_fee_percent': 'float',
        'billing': 'str',
        'cancel_at_period_end': 'bool',
        'canceled_at': 'int',
        'created': 'int',
        'current_period_end': 'int',
        'current_period_start': 'int',
        'customer': 'str',
        'days_until_due': 'int',
        'discount': 'Discount',
        'ended_at': 'int',
        'metadata': 'dict(str, str)',
        'plan': 'Plan',
        'quantity': 'int',
        'start': 'int',
        'status': 'str',
        'tax_percent': 'float',
        'trial_end': 'int',
        'trial_start': 'int',
        'customer_object': 'Customer',
        'subscription_items': 'SubscriptionItemCollection'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'application_fee_percent': 'applicationFeePercent',
        'billing': 'billing',
        'cancel_at_period_end': 'cancelAtPeriodEnd',
        'canceled_at': 'canceledAt',
        'created': 'created',
        'current_period_end': 'currentPeriodEnd',
        'current_period_start': 'currentPeriodStart',
        'customer': 'customer',
        'days_until_due': 'daysUntilDue',
        'discount': 'discount',
        'ended_at': 'endedAt',
        'metadata': 'metadata',
        'plan': 'plan',
        'quantity': 'quantity',
        'start': 'start',
        'status': 'status',
        'tax_percent': 'taxPercent',
        'trial_end': 'trialEnd',
        'trial_start': 'trialStart',
        'customer_object': 'customerObject',
        'subscription_items': 'subscriptionItems'
    }

    def __init__(self, id=None, object=None, application_fee_percent=None, billing=None, cancel_at_period_end=None, canceled_at=None, created=None, current_period_end=None, current_period_start=None, customer=None, days_until_due=None, discount=None, ended_at=None, metadata=None, plan=None, quantity=None, start=None, status=None, tax_percent=None, trial_end=None, trial_start=None, customer_object=None, subscription_items=None):  # noqa: E501
        """Subscription - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._application_fee_percent = None
        self._billing = None
        self._cancel_at_period_end = None
        self._canceled_at = None
        self._created = None
        self._current_period_end = None
        self._current_period_start = None
        self._customer = None
        self._days_until_due = None
        self._discount = None
        self._ended_at = None
        self._metadata = None
        self._plan = None
        self._quantity = None
        self._start = None
        self._status = None
        self._tax_percent = None
        self._trial_end = None
        self._trial_start = None
        self._customer_object = None
        self._subscription_items = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if application_fee_percent is not None:
            self.application_fee_percent = application_fee_percent
        if billing is not None:
            self.billing = billing
        if cancel_at_period_end is not None:
            self.cancel_at_period_end = cancel_at_period_end
        if canceled_at is not None:
            self.canceled_at = canceled_at
        if created is not None:
            self.created = created
        if current_period_end is not None:
            self.current_period_end = current_period_end
        if current_period_start is not None:
            self.current_period_start = current_period_start
        if customer is not None:
            self.customer = customer
        if days_until_due is not None:
            self.days_until_due = days_until_due
        if discount is not None:
            self.discount = discount
        if ended_at is not None:
            self.ended_at = ended_at
        if metadata is not None:
            self.metadata = metadata
        if plan is not None:
            self.plan = plan
        if quantity is not None:
            self.quantity = quantity
        if start is not None:
            self.start = start
        if status is not None:
            self.status = status
        if tax_percent is not None:
            self.tax_percent = tax_percent
        if trial_end is not None:
            self.trial_end = trial_end
        if trial_start is not None:
            self.trial_start = trial_start
        if customer_object is not None:
            self.customer_object = customer_object
        if subscription_items is not None:
            self.subscription_items = subscription_items

    @property
    def id(self):
        """Gets the id of this Subscription.  # noqa: E501


        :return: The id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subscription.


        :param id: The id of this Subscription.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this Subscription.  # noqa: E501


        :return: The object of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this Subscription.


        :param object: The object of this Subscription.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def application_fee_percent(self):
        """Gets the application_fee_percent of this Subscription.  # noqa: E501


        :return: The application_fee_percent of this Subscription.  # noqa: E501
        :rtype: float
        """
        return self._application_fee_percent

    @application_fee_percent.setter
    def application_fee_percent(self, application_fee_percent):
        """Sets the application_fee_percent of this Subscription.


        :param application_fee_percent: The application_fee_percent of this Subscription.  # noqa: E501
        :type: float
        """

        self._application_fee_percent = application_fee_percent

    @property
    def billing(self):
        """Gets the billing of this Subscription.  # noqa: E501


        :return: The billing of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._billing

    @billing.setter
    def billing(self, billing):
        """Sets the billing of this Subscription.


        :param billing: The billing of this Subscription.  # noqa: E501
        :type: str
        """

        self._billing = billing

    @property
    def cancel_at_period_end(self):
        """Gets the cancel_at_period_end of this Subscription.  # noqa: E501


        :return: The cancel_at_period_end of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._cancel_at_period_end

    @cancel_at_period_end.setter
    def cancel_at_period_end(self, cancel_at_period_end):
        """Sets the cancel_at_period_end of this Subscription.


        :param cancel_at_period_end: The cancel_at_period_end of this Subscription.  # noqa: E501
        :type: bool
        """

        self._cancel_at_period_end = cancel_at_period_end

    @property
    def canceled_at(self):
        """Gets the canceled_at of this Subscription.  # noqa: E501


        :return: The canceled_at of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._canceled_at

    @canceled_at.setter
    def canceled_at(self, canceled_at):
        """Sets the canceled_at of this Subscription.


        :param canceled_at: The canceled_at of this Subscription.  # noqa: E501
        :type: int
        """

        self._canceled_at = canceled_at

    @property
    def created(self):
        """Gets the created of this Subscription.  # noqa: E501


        :return: The created of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Subscription.


        :param created: The created of this Subscription.  # noqa: E501
        :type: int
        """

        self._created = created

    @property
    def current_period_end(self):
        """Gets the current_period_end of this Subscription.  # noqa: E501


        :return: The current_period_end of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._current_period_end

    @current_period_end.setter
    def current_period_end(self, current_period_end):
        """Sets the current_period_end of this Subscription.


        :param current_period_end: The current_period_end of this Subscription.  # noqa: E501
        :type: int
        """

        self._current_period_end = current_period_end

    @property
    def current_period_start(self):
        """Gets the current_period_start of this Subscription.  # noqa: E501


        :return: The current_period_start of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._current_period_start

    @current_period_start.setter
    def current_period_start(self, current_period_start):
        """Sets the current_period_start of this Subscription.


        :param current_period_start: The current_period_start of this Subscription.  # noqa: E501
        :type: int
        """

        self._current_period_start = current_period_start

    @property
    def customer(self):
        """Gets the customer of this Subscription.  # noqa: E501


        :return: The customer of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this Subscription.


        :param customer: The customer of this Subscription.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def days_until_due(self):
        """Gets the days_until_due of this Subscription.  # noqa: E501


        :return: The days_until_due of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._days_until_due

    @days_until_due.setter
    def days_until_due(self, days_until_due):
        """Sets the days_until_due of this Subscription.


        :param days_until_due: The days_until_due of this Subscription.  # noqa: E501
        :type: int
        """

        self._days_until_due = days_until_due

    @property
    def discount(self):
        """Gets the discount of this Subscription.  # noqa: E501


        :return: The discount of this Subscription.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this Subscription.


        :param discount: The discount of this Subscription.  # noqa: E501
        :type: Discount
        """

        self._discount = discount

    @property
    def ended_at(self):
        """Gets the ended_at of this Subscription.  # noqa: E501


        :return: The ended_at of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this Subscription.


        :param ended_at: The ended_at of this Subscription.  # noqa: E501
        :type: int
        """

        self._ended_at = ended_at

    @property
    def metadata(self):
        """Gets the metadata of this Subscription.  # noqa: E501


        :return: The metadata of this Subscription.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Subscription.


        :param metadata: The metadata of this Subscription.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def plan(self):
        """Gets the plan of this Subscription.  # noqa: E501


        :return: The plan of this Subscription.  # noqa: E501
        :rtype: Plan
        """
        return self._plan

    @plan.setter
    def plan(self, plan):
        """Sets the plan of this Subscription.


        :param plan: The plan of this Subscription.  # noqa: E501
        :type: Plan
        """

        self._plan = plan

    @property
    def quantity(self):
        """Gets the quantity of this Subscription.  # noqa: E501


        :return: The quantity of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this Subscription.


        :param quantity: The quantity of this Subscription.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def start(self):
        """Gets the start of this Subscription.  # noqa: E501


        :return: The start of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this Subscription.


        :param start: The start of this Subscription.  # noqa: E501
        :type: int
        """

        self._start = start

    @property
    def status(self):
        """Gets the status of this Subscription.  # noqa: E501


        :return: The status of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Subscription.


        :param status: The status of this Subscription.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tax_percent(self):
        """Gets the tax_percent of this Subscription.  # noqa: E501


        :return: The tax_percent of this Subscription.  # noqa: E501
        :rtype: float
        """
        return self._tax_percent

    @tax_percent.setter
    def tax_percent(self, tax_percent):
        """Sets the tax_percent of this Subscription.


        :param tax_percent: The tax_percent of this Subscription.  # noqa: E501
        :type: float
        """

        self._tax_percent = tax_percent

    @property
    def trial_end(self):
        """Gets the trial_end of this Subscription.  # noqa: E501


        :return: The trial_end of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._trial_end

    @trial_end.setter
    def trial_end(self, trial_end):
        """Sets the trial_end of this Subscription.


        :param trial_end: The trial_end of this Subscription.  # noqa: E501
        :type: int
        """

        self._trial_end = trial_end

    @property
    def trial_start(self):
        """Gets the trial_start of this Subscription.  # noqa: E501


        :return: The trial_start of this Subscription.  # noqa: E501
        :rtype: int
        """
        return self._trial_start

    @trial_start.setter
    def trial_start(self, trial_start):
        """Sets the trial_start of this Subscription.


        :param trial_start: The trial_start of this Subscription.  # noqa: E501
        :type: int
        """

        self._trial_start = trial_start

    @property
    def customer_object(self):
        """Gets the customer_object of this Subscription.  # noqa: E501


        :return: The customer_object of this Subscription.  # noqa: E501
        :rtype: Customer
        """
        return self._customer_object

    @customer_object.setter
    def customer_object(self, customer_object):
        """Sets the customer_object of this Subscription.


        :param customer_object: The customer_object of this Subscription.  # noqa: E501
        :type: Customer
        """

        self._customer_object = customer_object

    @property
    def subscription_items(self):
        """Gets the subscription_items of this Subscription.  # noqa: E501


        :return: The subscription_items of this Subscription.  # noqa: E501
        :rtype: SubscriptionItemCollection
        """
        return self._subscription_items

    @subscription_items.setter
    def subscription_items(self, subscription_items):
        """Sets the subscription_items of this Subscription.


        :param subscription_items: The subscription_items of this Subscription.  # noqa: E501
        :type: SubscriptionItemCollection
        """

        self._subscription_items = subscription_items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTFriendInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email': 'str',
        'token': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'image_url': 'str',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'email': 'email',
        'token': 'token',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'image_url': 'imageUrl',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, email=None, token=None, first_name=None, last_name=None, image_url=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTFriendInfo - a model defined in OpenAPI"""  # noqa: E501

        self._email = None
        self._token = None
        self._first_name = None
        self._last_name = None
        self._image_url = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if token is not None:
            self.token = token
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if image_url is not None:
            self.image_url = image_url
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def email(self):
        """Gets the email of this BTFriendInfo.  # noqa: E501


        :return: The email of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this BTFriendInfo.


        :param email: The email of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def token(self):
        """Gets the token of this BTFriendInfo.  # noqa: E501


        :return: The token of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this BTFriendInfo.


        :param token: The token of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def first_name(self):
        """Gets the first_name of this BTFriendInfo.  # noqa: E501


        :return: The first_name of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this BTFriendInfo.


        :param first_name: The first_name of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this BTFriendInfo.  # noqa: E501


        :return: The last_name of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this BTFriendInfo.


        :param last_name: The last_name of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def image_url(self):
        """Gets the image_url of this BTFriendInfo.  # noqa: E501


        :return: The image_url of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this BTFriendInfo.


        :param image_url: The image_url of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    @property
    def name(self):
        """Gets the name of this BTFriendInfo.  # noqa: E501


        :return: The name of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTFriendInfo.


        :param name: The name of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTFriendInfo.  # noqa: E501


        :return: The id of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTFriendInfo.


        :param id: The id of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTFriendInfo.  # noqa: E501


        :return: The href of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTFriendInfo.


        :param href: The href of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTFriendInfo.  # noqa: E501


        :return: The view_ref of this BTFriendInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTFriendInfo.


        :param view_ref: The view_ref of this BTFriendInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTFriendInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
